@@ -27,6 +27,12 @@ typedef ze_event_handle_t zex_event_handle_t;
 
 #define ZEX_BIT(_i) (1 << _i)
 
+#if defined(__cplusplus)
+#define EXTENDED_ENUM(ENUM_T, VALUE) static_cast<ENUM_T>(VALUE) // NOLINT(clang-analyzer-optin.core.EnumCastOutOfRange)
+#else
+#define EXTENDED_ENUM(ENUM_T, VALUE) ((ENUM_T)VALUE)
+#endif
+
 typedef uint32_t zex_mem_action_scope_flags_t;
 typedef enum _zex_mem_action_scope_flag_t {
     ZEX_MEM_ACTION_SCOPE_FLAG_SUBDEVICE = ZEX_BIT(0),
@@ -178,8 +184,9 @@ typedef enum _zex_counter_based_event_exp_flag_t {
     ZEX_COUNTER_BASED_EVENT_FLAG_KERNEL_TIMESTAMP = ZE_BIT(4),        ///< Event contains kernel timestamps
     ZEX_COUNTER_BASED_EVENT_FLAG_KERNEL_MAPPED_TIMESTAMP = ZE_BIT(5), ///< Event contains kernel timestamps synchronized to host time domain.
                                                                       ///< Cannot be combined with::ZEX_COUNTER_BASED_EVENT_FLAG_KERNEL_TIMESTAMP
-    ZEX_COUNTER_BASED_EVENT_FLAG_GRAPH_EXTERNAL_EVENT = ZE_BIT(6),    ///< Event when is used in graph record & replay, can be used outside
-                                                                      ///< recorded graph for synchronization (using as wait event or for host synchronization)
+    ZEX_COUNTER_BASED_EVENT_FLAG_EXTERNAL = ZE_BIT(6),                ///< Events with this flag, when used in graph record and replay or
+                                                                      ///< in a cloned command list, can also be used for external synchronization,
+                                                                      ///< for example, as a wait event outside of a graph or for a host synchronization.
     ZEX_COUNTER_BASED_EVENT_FLAG_FORCE_UINT32 = 0x7fffffff
 
 } zex_counter_based_event_exp_flag_t;
@@ -233,6 +240,12 @@ typedef struct _zex_counter_based_event_external_storage_properties_t {
     uint64_t completionValue;      ///< [in] final completion value, when value under deviceAddress is equal or greater then this value then event is considered as completed
 } zex_counter_based_event_external_storage_properties_t;
 
+typedef enum _zex_verify_memory_compare_type_t {
+    ZEX_VERIFY_MEMORY_COMPARE_EQUAL = 0,                // compare memory for equality
+    ZEX_VERIFY_MEMORY_COMPARE_NOT_EQUAL = 1,            // compare memory for inequality
+    ZEX_VERIFY_MEMORY_COMPARE_FORCE_UINT32 = 0x7fffffff ///< Value marking end of ZEX_VERIFY_MEMORY_COMPARE* ENUMs
+} zex_verify_memory_compare_type_t;
+
 #if defined(__cplusplus)
 } // extern "C"
 #endif
